@@ -5,4 +5,4 @@
 #'
 #' @name ggperiodic
 #' @docType package
-'_PACKAGE'
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
